node

package
v0.0.0-...-9cb9798 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 10, 2024 License: AGPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the node type in the database.
	Label = "node"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldHost holds the string denoting the host field in the database.
	FieldHost = "host"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// Table holds the table name of the node in the database.
	Table = "nodes"
)

Variables

var (
	// NameValidator is a validator for the "name" field. It is called by the builders before save.
	NameValidator func(string) error
	// HostValidator is a validator for the "host" field. It is called by the builders before save.
	HostValidator func(string) error
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
)

Columns holds all SQL columns for node fields.

Functions

func And

func And(predicates ...predicate.Node) predicate.Node

And groups predicates with the AND operator between them.

func CreatedAt

func CreatedAt(v time.Time) predicate.Node

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.Node

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.Node

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.Node

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.Node

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.Node

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.Node

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.Node

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.Node

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func Host

func Host(v string) predicate.Node

Host applies equality check predicate on the "host" field. It's identical to HostEQ.

func HostContains

func HostContains(v string) predicate.Node

HostContains applies the Contains predicate on the "host" field.

func HostContainsFold

func HostContainsFold(v string) predicate.Node

HostContainsFold applies the ContainsFold predicate on the "host" field.

func HostEQ

func HostEQ(v string) predicate.Node

HostEQ applies the EQ predicate on the "host" field.

func HostEqualFold

func HostEqualFold(v string) predicate.Node

HostEqualFold applies the EqualFold predicate on the "host" field.

func HostGT

func HostGT(v string) predicate.Node

HostGT applies the GT predicate on the "host" field.

func HostGTE

func HostGTE(v string) predicate.Node

HostGTE applies the GTE predicate on the "host" field.

func HostHasPrefix

func HostHasPrefix(v string) predicate.Node

HostHasPrefix applies the HasPrefix predicate on the "host" field.

func HostHasSuffix

func HostHasSuffix(v string) predicate.Node

HostHasSuffix applies the HasSuffix predicate on the "host" field.

func HostIn

func HostIn(vs ...string) predicate.Node

HostIn applies the In predicate on the "host" field.

func HostLT

func HostLT(v string) predicate.Node

HostLT applies the LT predicate on the "host" field.

func HostLTE

func HostLTE(v string) predicate.Node

HostLTE applies the LTE predicate on the "host" field.

func HostNEQ

func HostNEQ(v string) predicate.Node

HostNEQ applies the NEQ predicate on the "host" field.

func HostNotIn

func HostNotIn(vs ...string) predicate.Node

HostNotIn applies the NotIn predicate on the "host" field.

func ID

func ID(id int) predicate.Node

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.Node

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.Node

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.Node

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.Node

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.Node

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.Node

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.Node

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.Node

IDNotIn applies the NotIn predicate on the ID field.

func Name

func Name(v string) predicate.Node

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.Node

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.Node

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.Node

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.Node

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.Node

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.Node

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.Node

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.Node

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.Node

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.Node

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.Node

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.Node

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.Node

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Node) predicate.Node

Or groups predicates with the OR operator between them.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Node queries.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByHost

func ByHost(opts ...sql.OrderTermOption) OrderOption

ByHost orders the results by the host field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

Jump to