Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Node) predicate.Node
- func CreatedAt(v time.Time) predicate.Node
- func CreatedAtEQ(v time.Time) predicate.Node
- func CreatedAtGT(v time.Time) predicate.Node
- func CreatedAtGTE(v time.Time) predicate.Node
- func CreatedAtIn(vs ...time.Time) predicate.Node
- func CreatedAtLT(v time.Time) predicate.Node
- func CreatedAtLTE(v time.Time) predicate.Node
- func CreatedAtNEQ(v time.Time) predicate.Node
- func CreatedAtNotIn(vs ...time.Time) predicate.Node
- func Host(v string) predicate.Node
- func HostContains(v string) predicate.Node
- func HostContainsFold(v string) predicate.Node
- func HostEQ(v string) predicate.Node
- func HostEqualFold(v string) predicate.Node
- func HostGT(v string) predicate.Node
- func HostGTE(v string) predicate.Node
- func HostHasPrefix(v string) predicate.Node
- func HostHasSuffix(v string) predicate.Node
- func HostIn(vs ...string) predicate.Node
- func HostLT(v string) predicate.Node
- func HostLTE(v string) predicate.Node
- func HostNEQ(v string) predicate.Node
- func HostNotIn(vs ...string) predicate.Node
- func ID(id int) predicate.Node
- func IDEQ(id int) predicate.Node
- func IDGT(id int) predicate.Node
- func IDGTE(id int) predicate.Node
- func IDIn(ids ...int) predicate.Node
- func IDLT(id int) predicate.Node
- func IDLTE(id int) predicate.Node
- func IDNEQ(id int) predicate.Node
- func IDNotIn(ids ...int) predicate.Node
- func Name(v string) predicate.Node
- func NameContains(v string) predicate.Node
- func NameContainsFold(v string) predicate.Node
- func NameEQ(v string) predicate.Node
- func NameEqualFold(v string) predicate.Node
- func NameGT(v string) predicate.Node
- func NameGTE(v string) predicate.Node
- func NameHasPrefix(v string) predicate.Node
- func NameHasSuffix(v string) predicate.Node
- func NameIn(vs ...string) predicate.Node
- func NameLT(v string) predicate.Node
- func NameLTE(v string) predicate.Node
- func NameNEQ(v string) predicate.Node
- func NameNotIn(vs ...string) predicate.Node
- func Not(p predicate.Node) predicate.Node
- func Or(predicates ...predicate.Node) predicate.Node
- func ValidColumn(column string) bool
- type OrderOption
Constants ¶
const ( // Label holds the string label denoting the node type in the database. Label = "node" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldHost holds the string denoting the host field in the database. FieldHost = "host" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // Table holds the table name of the node in the database. Table = "nodes" )
Variables ¶
var ( // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error // HostValidator is a validator for the "host" field. It is called by the builders before save. HostValidator func(string) error // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time )
var Columns = []string{ FieldID, FieldName, FieldHost, FieldCreatedAt, }
Columns holds all SQL columns for node fields.
Functions ¶
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func HostContains ¶
HostContains applies the Contains predicate on the "host" field.
func HostContainsFold ¶
HostContainsFold applies the ContainsFold predicate on the "host" field.
func HostEqualFold ¶
HostEqualFold applies the EqualFold predicate on the "host" field.
func HostHasPrefix ¶
HostHasPrefix applies the HasPrefix predicate on the "host" field.
func HostHasSuffix ¶
HostHasSuffix applies the HasSuffix predicate on the "host" field.
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Node queries.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByHost ¶
func ByHost(opts ...sql.OrderTermOption) OrderOption
ByHost orders the results by the host field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.